@@ -11,7 +11,7 @@ WebService::Audioscrobbler::Artist - An object-oriented interface to the Audiosc
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # postfix related accessors
 CLASS->mk_classaccessor("base_resource_path"  => "artist");
@@ -215,7 +215,7 @@ derived from.
 
 sub resource_path {
     my $self = shift;
-    URI->new( join '/', $self->base_resource_path, $self->name );
+    $self->uri_builder( $self->name );
 }
 
 =head1 AUTHOR
